@@ -62,7 +62,7 @@ agora_local_user_subscribe_all_audio.argtypes = [AGORA_HANDLE]
 
 agora_local_user_unsubscribe_audio = agora_lib.agora_local_user_unsubscribe_audio
 agora_local_user_unsubscribe_audio.restype = AGORA_API_C_INT
-agora_local_user_unsubscribe_audio.argtypes = [AGORA_HANDLE, ctypes.c_uint]
+agora_local_user_unsubscribe_audio.argtypes = [AGORA_HANDLE, user_id_t]
 
 agora_local_user_unsubscribe_all_audio = agora_lib.agora_local_user_unsubscribe_all_audio
 agora_local_user_unsubscribe_all_audio.restype = AGORA_API_C_INT
@@ -184,7 +184,7 @@ agora_local_user_subscribe_all_video.argtypes = [AGORA_HANDLE, ctypes.POINTER(Vi
 
 agora_local_user_unsubscribe_video = agora_lib.agora_local_user_unsubscribe_video
 agora_local_user_unsubscribe_video.restype = AGORA_API_C_INT
-agora_local_user_unsubscribe_video.argtypes = [AGORA_HANDLE, ctypes.c_uint]
+agora_local_user_unsubscribe_video.argtypes = [AGORA_HANDLE, user_id_t]
 
 agora_local_user_unsubscribe_all_video = agora_lib.agora_local_user_unsubscribe_all_video
 agora_local_user_unsubscribe_all_video.restype = AGORA_API_C_INT
@@ -223,6 +223,15 @@ agora_local_user_set_audio_scenario = agora_lib.agora_local_user_set_audio_scena
 agora_local_user_set_audio_scenario.restype = AGORA_API_C_INT
 agora_local_user_set_audio_scenario.argtypes = [AGORA_HANDLE, ctypes.c_int]
 
+#verison 2.2.0
+
+#AGORA_API_C_INT agora_local_user_send_audio_meta_data(AGORA_HANDLE agora_local_user, const char* meta_data, size_t length);
+agora_local_user_send_aduio_meta_data = agora_lib.agora_local_user_send_audio_meta_data
+agora_local_user_send_aduio_meta_data.restype = AGORA_API_C_INT
+agora_local_user_send_aduio_meta_data.argtypes = [AGORA_HANDLE, ctypes.c_char_p, ctypes.c_size_t]
+
+
+
 
 class LocalUser:
     def __init__(self, local_user_handle, connection):
@@ -361,7 +370,13 @@ class LocalUser:
         return ret
 
     def subscribe_audio(self, user_id):
-        ret = agora_local_user_subscribe_audio(self.user_handle, ctypes.c_char_p(user_id.encode()))
+        if user_id is None:
+            return -1
+        uid_str = user_id.encode('utf-8')
+        #ret = agora_local_user_subscribe_audio(self.user_handle, ctypes.create_string_buffer(uid_str))
+        # note：both ctypes.create_string_buffer and ctypes.c_char_p are all can change python's str to c_char_p
+        # but ctypes.c_char_p is more suitable for this case for the c api never change the content of c_char_p
+        ret = agora_local_user_subscribe_audio(self.user_handle, ctypes.c_char_p(uid_str))
         return ret
 
     def subscribe_all_audio(self):
@@ -369,7 +384,11 @@ class LocalUser:
         return ret
 
     def unsubscribe_audio(self, user_id):
-        ret = agora_local_user_unsubscribe_audio(self.user_handle, ctypes.c_char_p(user_id.encode()))
+        #validity check
+        if user_id is None:
+            return -1
+        uid_str = user_id.encode('utf-8')
+        ret = agora_local_user_unsubscribe_audio(self.user_handle, ctypes.c_char_p(uid_str))
         if ret < 0:
             logger.error("Failed to unsubscribe audio")
         else:
@@ -485,18 +504,33 @@ class LocalUser:
     #     return ret
 
     def subscribe_video(self, user_id, options: VideoSubscriptionOptions):
-        user_id_t = user_id.encode('utf-8')
+        if user_id is None:
+            return -1
+        uid_str = user_id.encode('utf-8')
 
-        ret = agora_local_user_subscribe_video(self.user_handle, user_id_t, ctypes.byref(options))
+        
+        if options is  None:
+            inner = VideoSubscriptionOptionsInner()
+        else:
+            inner = VideoSubscriptionOptionsInner.create(options)
+
+        c_ptr = ctypes.byref(inner)
+        ret = agora_local_user_subscribe_video(self.user_handle, ctypes.c_char_p(uid_str), c_ptr)
         return ret
 
     def subscribe_all_video(self, options: VideoSubscriptionOptions):
-        ret = agora_local_user_subscribe_all_video(self.user_handle, ctypes.byref(VideoSubscriptionOptionsInner.create(options)))
+        if options is  None:
+            inner = VideoSubscriptionOptionsInner()
+        else:
+            inner = VideoSubscriptionOptionsInner.create(options)
+        ret = agora_local_user_subscribe_all_video(self.user_handle, ctypes.byref(inner))
         return ret
 
     def unsubscribe_video(self, user_id):
-        user_id_t = user_id.encode('utf-8')
-        ret = agora_local_user_unsubscribe_video(self.user_handle, user_id_t)
+        if user_id is None:
+            return -1
+        uid_str = user_id.encode('utf-8')
+        ret = agora_local_user_unsubscribe_video(self.user_handle, ctypes.c_char_p(uid_str))
         if ret < 0:
             logger.error("Failed to unsubscribe video")
         else:
@@ -569,3 +603,12 @@ class LocalUser:
     def set_audio_scenario(self, scenario_type: AudioScenarioType):
         ret = agora_local_user_set_audio_scenario(self.user_handle, scenario_type.value)
         return ret
+    # data can be str or bytes/bytearray object,is diff to send_sream_message which is a str object
+    def send_audio_meta_data(self, data):
+        # chang to ctypes.c_char_p
+        if isinstance(data, str):
+            data = data.encode('utf-8')
+        c_data = ctypes.create_string_buffer(bytes(data))
+        size = len(data)
+        ret = agora_local_user_send_aduio_meta_data(self.user_handle, c_data, ctypes.c_size_t(size))
+        return ret
